@@ -12,7 +12,7 @@ end
 module Gist
   extend self
 
-  VERSION = '4.6.1'
+  VERSION = '4.6.2'
 
   # A list of clipboard commands with copy and paste support.
   CLIPBOARD_COMMANDS = {
@@ -76,10 +76,14 @@ module Gist
   #
   # @see http://developer.github.com/v3/gists/
   def gist(content, options = {})
-    filename = options[:filename] || "a.rb"
+    filename = options[:filename] || default_filename
     multi_gist({filename => content}, options)
   end
 
+  def default_filename
+    "gistfile1.txt"
+  end
+
   # Upload a gist to https://gist.github.com
   #
   # @param [Hash] files  the code you'd like to gist: filename => content
@@ -92,6 +96,7 @@ module Gist
   # @option options [String] :update  the URL or id of a gist to update
   # @option options [Boolean] :copy  (false) Copy resulting URL to clipboard, if successful.
   # @option options [Boolean] :open  (false) Open the resulting URL in a browser.
+  # @option options [Boolean] :skip_empty (false) Skip gisting empty files.
   # @option options [Symbol] :output (:all) The type of return value you'd like:
   #   :html_url gives a String containing the url to the gist in a browser
   #   :short_url gives a String contianing a  git.io url that redirects to html_url
@@ -110,10 +115,16 @@ module Gist
     json[:files] = {}
 
     files.each_pair do |(name, content)|
-      raise "Cannot gist empty files" if content.to_s.strip == ""
-      json[:files][File.basename(name)] = {:content => content}
+      if content.to_s.strip == ""
+        raise "Cannot gist empty files" unless options[:skip_empty]
+      else
+        name = name == "-" ? default_filename : File.basename(name)
+        json[:files][name] = {:content => content}
+      end
     end
 
+    return if json[:files].empty? && options[:skip_empty]
+
     existing_gist = options[:update].to_s.split("/").last
     if options[:anonymous]
       access_token = nil
@@ -203,6 +214,12 @@ module Gist
 
   def read_gist(id, file_name=nil)
     url = "#{base_path}/gists/#{id}"
+
+    access_token = auth_token()
+    if access_token.to_s != ''
+      url << "?access_token=" << CGI.escape(access_token)
+    end
+
     request = Net::HTTP::Get.new(url)
     response = http(api_url, request)
 
